window.Gleam.initSearch([{"doc":"gclog","title":"gclog","content":"# gclog\n\n[![Package Version](https://img.shields.io/hexpm/v/gclog)](https://hex.pm/packages/gclog)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gclog/)\n\n```sh\ngleam add gclog\n```\n\nWriting string messages to Google Cloud Logging.\n\n```gleam\nimport gclog\nimport gclog/entry\nimport gclog/severity\nimport gleam/json\n\npub fn main() {\n    let logger = gclog.new_stderr(severity.Debug, json.string)\n\n    logger\n    |&gt; gclog.info(&quot;Hello, world!&quot;)\n}\n```\n\nWriting structured logs to Google Cloud Logging.\n\n&gt; Please note there is a limitation with structured logs where all fields will be nested as so: `{&quot;jsonPayload&quot;:{&quot;message&quot;:{&lt;your fields here&gt;}}`\n\n```gleam\nimport gclog\nimport gclog/entry\nimport gclog/severity\nimport gleam/json.{type Json}\n\npub type Message {\n    Message(id: String, client: String, content: String)\n}\n\npub fn message_serializer(m: Message) -&gt; Json {\n    json.object([\n        #(&quot;id&quot;, m.id),\n        #(&quot;client&quot;, m.client),\n        #(&quot;content&quot;, m.content),\n    ])\n}\n\npub fn main() {\n    let logger = gclog.new_stderr(severity.Debug, message_serializer)\n\n    logger\n    |&gt; gclog.info(Message(id: &quot;12345&quot;, client: &quot;Some Client&quot;, content: &quot;Hello, world!&quot;))\n}\n```\n\nWriting complete Entries\n\n```gleam\nimport gclog\nimport gclog/entry\nimport gclog/severity\n\n// Note that you will need to provide the serializer in both the\n// Logger constructor as well as manually serializing the value in\n// `entry.new`.\nlet logger = gclog.new_stderr(severity.Debug, json.string)\n\nlogger\n|&gt; gclog.entry(\n    entry.new(severity.Notice, json.string(&quot;Hello, world&quot;))\n    |&gt; entry.with_source_location(line: 10, file: &quot;app.gleam&quot;, function: &quot;main&quot;)\n    |&gt; entry.with_trace(entry.Trace(project: &quot;my-project&quot;, id: &quot;12345&quot;))\n    |&gt; entry.with_labels(dict.from_list([#(&quot;A&quot;, &quot;b&quot;)]))\n    |&gt; entry.with_trace_sampled(True)\n    |&gt; entry.with_span_id(&quot;d39223e101960076&quot;),\n)\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/gclog&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"gclog/severity","title":"Severity","content":"pub type Severity {\n  Default\n  Debug\n  Info\n  Notice\n  Warning\n  Error\n  Critical\n  Alert\n  Emergency\n}\n The severity of the event described in a log entry.\nDefault\n\n\nDebug\n\n\nInfo\n\n\nNotice\n\n\nWarning\n\n\nError\n\n\nCritical\n\n\nAlert\n\n\nEmergency\n\n\nSynonyms:\ngclog/severity.Severity\ngclog/severity Severity","url":"gclog/severity.html#Severity"},{"doc":"gclog/severity","title":"to_int","content":"pub fn to_int(severity: Severity) -&gt; Int\n Convert a severity to a numerical representation.\nSynonyms:\ngclog/severity.to_int\ngclog/severity to_int","url":"gclog/severity.html#to_int"},{"doc":"gclog/severity","title":"to_string","content":"pub fn to_string(severity: Severity) -&gt; String\n Convert a severity to a text representation.\nSynonyms:\ngclog/severity.to_string\ngclog/severity to_string","url":"gclog/severity.html#to_string"},{"doc":"gclog/severity","title":"gclog/severity","content":" Contains the Severity type and helper methods.","url":"gclog/severity.html"},{"doc":"gclog/entry","title":"Entry","content":"pub type Entry {\n  Entry(\n    severity: Severity,\n    message: json.Json,\n    labels: Option(Dict(String, String)),\n    trace: Option(Trace),\n    span_id: Option(String),\n    trace_sampled: Option(Bool),\n    source_location: Option(SourceLocation),\n  )\n}\n A fairly complete Google Cloud Logging Entry.\nEntry(\n  severity: Severity,\n  message: json.Json,\n  labels: Option(Dict(String, String)),\n  trace: Option(Trace),\n  span_id: Option(String),\n  trace_sampled: Option(Bool),\n  source_location: Option(SourceLocation),\n)\n\n\nSynonyms:\ngclog/entry.Entry\ngclog/entry Entry","url":"gclog/entry.html#Entry"},{"doc":"gclog/entry","title":"SourceLocation","content":"pub type SourceLocation {\n  SourceLocation(\n    file: Option(String),\n    line: Option(Int),\n    function: Option(String),\n  )\n}\n Represents a location in source code.\nSourceLocation(\n  file: Option(String),\n  line: Option(Int),\n  function: Option(String),\n)\n\n\nSynonyms:\ngclog/entry.SourceLocation\ngclog/entry SourceLocation","url":"gclog/entry.html#SourceLocation"},{"doc":"gclog/entry","title":"Trace","content":"pub type Trace {\n  Trace(project: String, id: String)\n}\n Validate traces.\n Ensures the project id and trace id are provided.\nTrace(project: String, id: String)\n\n\nSynonyms:\ngclog/entry.Trace\ngclog/entry Trace","url":"gclog/entry.html#Trace"},{"doc":"gclog/entry","title":"new","content":"pub fn new(severity: Severity, message: Json) -&gt; Entry\n Create a new, minimal log Entry.\nSynonyms:\ngclog/entry.new\ngclog/entry new","url":"gclog/entry.html#new"},{"doc":"gclog/entry","title":"with_labels","content":"pub fn with_labels(\n  entry: Entry,\n  labels: Dict(String, String),\n) -&gt; Entry\n Add labels to an existing Entry.\nSynonyms:\ngclog/entry.with_labels\ngclog/entry with_labels","url":"gclog/entry.html#with_labels"},{"doc":"gclog/entry","title":"with_source_location","content":"pub fn with_source_location(\n  entry: Entry,\n  line lineno: Int,\n  file fileloc: String,\n  function func: String,\n) -&gt; Entry\n Add where the log was called from to an existing Entry.\nSynonyms:\ngclog/entry.with_source_location\ngclog/entry with_source_location","url":"gclog/entry.html#with_source_location"},{"doc":"gclog/entry","title":"with_span_id","content":"pub fn with_span_id(entry: Entry, span_id: String) -&gt; Entry\n Add a span id to an existing Entry.\nSynonyms:\ngclog/entry.with_span_id\ngclog/entry with_span_id","url":"gclog/entry.html#with_span_id"},{"doc":"gclog/entry","title":"with_trace","content":"pub fn with_trace(entry: Entry, trace: Trace) -&gt; Entry\n Add a trace to an existing Entry.\nSynonyms:\ngclog/entry.with_trace\ngclog/entry with_trace","url":"gclog/entry.html#with_trace"},{"doc":"gclog/entry","title":"with_trace_sampled","content":"pub fn with_trace_sampled(\n  entry: Entry,\n  trace_sampled: Bool,\n) -&gt; Entry\n Specify the trace sampled field for an existing Entry.\nSynonyms:\ngclog/entry.with_trace_sampled\ngclog/entry with_trace_sampled","url":"gclog/entry.html#with_trace_sampled"},{"doc":"gclog/entry","title":"gclog/entry","content":" Types and methods to construct an Entry.","url":"gclog/entry.html"},{"doc":"gclog","title":"Logger","content":"pub type Logger(t, w) {\n  Logger(\n    severity: Severity,\n    writer: Writer(w),\n    serializer: Serializer(t),\n  )\n}\n Type used to write logs.\n Any log messages written using the Logger must be serializable\n using the provided Serializer.\n\n # Examples\n \n let logger = gclog.new_stderr(severity.Debug, json.string)\n\n logger\n |&gt; gclog.info(&quot;Hello, world!&quot;)\n \nLogger(\n  severity: Severity,\n  writer: Writer(w),\n  serializer: Serializer(t),\n)\n\n\nSynonyms:\ngclog.Logger\ngclog Logger","url":"gclog.html#Logger"},{"doc":"gclog","title":"Serializer","content":"pub type Serializer(t) =\n  fn(t) -&gt; json.Json\n Convert a type into JSON.\n\nSynonyms:\ngclog.Serializer\ngclog Serializer","url":"gclog.html#Serializer"},{"doc":"gclog","title":"Writer","content":"pub type Writer(t) =\n  fn(String) -&gt; t\n Write a log.\n\nSynonyms:\ngclog.Writer\ngclog Writer","url":"gclog.html#Writer"},{"doc":"gclog","title":"alert","content":"pub fn alert(logger: Logger(a, b), message: a) -&gt; Nil\n Log a message at the Alert level.\nSynonyms:\ngclog.alert\ngclog alert","url":"gclog.html#alert"},{"doc":"gclog","title":"critical","content":"pub fn critical(logger: Logger(a, b), message: a) -&gt; Nil\n Log a message at the Critical level.\nSynonyms:\ngclog.critical\ngclog critical","url":"gclog.html#critical"},{"doc":"gclog","title":"debug","content":"pub fn debug(logger: Logger(a, b), message: a) -&gt; Nil\n Log a message at the Debug level.\nSynonyms:\ngclog.debug\ngclog debug","url":"gclog.html#debug"},{"doc":"gclog","title":"default","content":"pub fn default(logger: Logger(a, b), message: a) -&gt; Nil\n Log a message at the Default level.\nSynonyms:\ngclog.default\ngclog default","url":"gclog.html#default"},{"doc":"gclog","title":"emergency","content":"pub fn emergency(logger: Logger(a, b), message: a) -&gt; Nil\n Log a message at the Emergency level.\nSynonyms:\ngclog.emergency\ngclog emergency","url":"gclog.html#emergency"},{"doc":"gclog","title":"entry","content":"pub fn entry(logger: Logger(a, b), entry: Entry) -&gt; Nil\n Log a complete Entry.\nSynonyms:\ngclog.entry\ngclog entry","url":"gclog.html#entry"},{"doc":"gclog","title":"error","content":"pub fn error(logger: Logger(a, b), message: a) -&gt; Nil\n Log a message at the Error level.\nSynonyms:\ngclog.error\ngclog error","url":"gclog.html#error"},{"doc":"gclog","title":"info","content":"pub fn info(logger: Logger(a, b), message: a) -&gt; Nil\n Log a message at the Info level.\nSynonyms:\ngclog.info\ngclog info","url":"gclog.html#info"},{"doc":"gclog","title":"log","content":"pub fn log(\n  logger: Logger(a, b),\n  message: a,\n  severity: Severity,\n) -&gt; Nil\n Log a message specifying the severity manually.\nSynonyms:\ngclog.log\ngclog log","url":"gclog.html#log"},{"doc":"gclog","title":"new_stderr","content":"pub fn new_stderr(\n  severity: Severity,\n  serializer: fn(a) -&gt; Json,\n) -&gt; Logger(a, Nil)\n Create a new logger that writes logs to stderr.\nSynonyms:\ngclog.new_stderr\ngclog new_stderr","url":"gclog.html#new_stderr"},{"doc":"gclog","title":"new_stdout","content":"pub fn new_stdout(\n  severity: Severity,\n  serializer: fn(a) -&gt; Json,\n) -&gt; Logger(a, Nil)\n Create a new logger that writes logs to stdout.\nSynonyms:\ngclog.new_stdout\ngclog new_stdout","url":"gclog.html#new_stdout"},{"doc":"gclog","title":"notice","content":"pub fn notice(logger: Logger(a, b), message: a) -&gt; Nil\n Log a message at the Notice level.\nSynonyms:\ngclog.notice\ngclog notice","url":"gclog.html#notice"},{"doc":"gclog","title":"warning","content":"pub fn warning(logger: Logger(a, b), message: a) -&gt; Nil\n Log a message at the Warning level.\nSynonyms:\ngclog.warning\ngclog warning","url":"gclog.html#warning"},{"doc":"gclog","title":"gclog","content":" Simple Google Cloud Platform compliant logging library.","url":"gclog.html"}]);